Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(391)

Unified Diff: chrome/browser/sync/glue/shared_change_processor_ref.h

Issue 10662035: [Sync] Put everything in sync/api into csync namespace (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Fix comments Created 8 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/sync/glue/shared_change_processor_ref.h
diff --git a/chrome/browser/sync/glue/shared_change_processor_ref.h b/chrome/browser/sync/glue/shared_change_processor_ref.h
index 98185fcdf05f928250b391f5dfd844029bf8df52..b618430b96caf2bc9d0686cb26711135ba84df7d 100644
--- a/chrome/browser/sync/glue/shared_change_processor_ref.h
+++ b/chrome/browser/sync/glue/shared_change_processor_ref.h
@@ -14,23 +14,23 @@
namespace browser_sync {
// A SyncChangeProcessor stub for interacting with a refcounted
// SharedChangeProcessor.
-class SharedChangeProcessorRef : public SyncChangeProcessor,
- public SyncErrorFactory {
+class SharedChangeProcessorRef : public csync::SyncChangeProcessor,
+ public csync::SyncErrorFactory {
public:
SharedChangeProcessorRef(
const scoped_refptr<browser_sync::SharedChangeProcessor>&
change_processor);
virtual ~SharedChangeProcessorRef();
- // SyncChangeProcessor implementation.
- virtual SyncError ProcessSyncChanges(
+ // csync::SyncChangeProcessor implementation.
+ virtual csync::SyncError ProcessSyncChanges(
const tracked_objects::Location& from_here,
- const SyncChangeList& change_list) OVERRIDE;
+ const csync::SyncChangeList& change_list) OVERRIDE;
- // SyncErrorFactory implementation.
- virtual SyncError CreateAndUploadError(
+ // csync::SyncErrorFactory implementation.
+ virtual csync::SyncError CreateAndUploadError(
const tracked_objects::Location& from_here,
const std::string& message) OVERRIDE;
« no previous file with comments | « chrome/browser/sync/glue/shared_change_processor_mock.h ('k') | chrome/browser/sync/glue/shared_change_processor_ref.cc » ('j') | no next file with comments »
@@ -14,23 +14,23 @@
namespace browser_sync {
-// A SyncChangeProcessor stub for interacting with a refcounted
+// A csync::SyncChangeProcessor stub for interacting with a refcounted
// SharedChangeProcessor.

Powered by Google App Engine
This is Rietveld 408576698